@@ -53,17 +53,6 @@
 # define __USE_POSIX
 #endif
 
-#ifndef _POSIX_C_SOURCE
-#define _POSIX_C_SOURCE 199506L
-#endif
-
-/* This for freebsd (needed on 3.2 at least) */
-#ifdef SOMEBSD
-# ifndef _POSIX_VERSION
-# define _POSIX_VERSION 199309L
-# endif
-#endif
-
 #include <stdio.h>
 #include <stdarg.h>
 #ifdef HAVE_SHOUT_SHOUT_H
@@ -110,12 +99,14 @@
 #include "ices_config.h"
 #include "playlist/playlist.h"
 
+ices_plugin_t *crossfade_plugin(int secs);
+
 #define BUFSIZE 8192
 #define ICES_DEFAULT_HOST "127.0.0.1"
 #define ICES_DEFAULT_PORT 8000
 #define ICES_DEFAULT_MOUNT "/ices"
 #define ICES_DEFAULT_PASSWORD "letmein"
-#define ICES_DEFAULT_PROTOCOL xaudiocast_protocol_e
+#define ICES_DEFAULT_PROTOCOL http_protocol_e
 #define ICES_DEFAULT_NAME "Default stream name"
 #define ICES_DEFAULT_GENRE "Default genre"
 #define ICES_DEFAULT_DESCRIPTION "Default description"
