@@ -20,7 +20,6 @@
 
 #include "definitions.h"
 
-shout_conn_t conn;
 ices_config_t ices_config;
 
 /* Global function definitions */
@@ -38,7 +37,7 @@ main (int argc, char **argv)
 	ices_setup_initialize ();
 	
 	/* Connect to server and keep streaming all the good stuff */
-	ices_stream_loop ();
+	ices_stream_loop (&ices_config);
 	
 	/* Not reached */
 	return 0;
