@@ -1,7 +1,7 @@
 /* icestypes.h
  * - Datatypes for ices
  * Copyright (c) 2000 Alexander Havng
- * Copyright (c) 2001-3 Brendan Cully <brendan@icecast.org>
+ * Copyright (c) 2001-4 Brendan Cully <brendan@xiph.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -75,22 +75,12 @@ typedef struct {
   void (*shutdown) (void);
 } playlist_module_t;
 
-typedef struct {
-  int daemon;
-  int verbose;
-  int reencode;
-  char *configfile;
-  char *base_directory;
-  FILE *logfile;
-
-  ices_stream_t* streams;
-  playlist_module_t pm;
-} ices_config_t;
-
 /* -- input stream types -- */
 typedef enum {
   ICES_INPUT_VORBIS,
-  ICES_INPUT_MP3
+  ICES_INPUT_MP3,
+  ICES_INPUT_MP4,
+  ICES_INPUT_FLAC
 } input_type_t;
 
 typedef struct _input_stream_t {
@@ -113,4 +103,28 @@ typedef struct _input_stream_t {
 		     int16_t* right);
   int (*close)(struct _input_stream_t* self);
 } input_stream_t;
+
+typedef struct _ices_plugin {
+  const char *name;
+
+  int (*init)(void);
+  void (*new_track)(input_stream_t *source);
+  int (*process)(int ilen, int16_t *il, int16_t *ir);
+  void (*shutdown)(void);
+
+  struct _ices_plugin *next;
+} ices_plugin_t;
+
+typedef struct {
+  int daemon;
+  int verbose;
+  int reencode;
+  char *configfile;
+  char *base_directory;
+  FILE *logfile;
+
+  ices_stream_t* streams;
+  playlist_module_t pm;
+  ices_plugin_t *plugins;
+} ices_config_t;
 #endif
