@@ -1,7 +1,7 @@
 /* setup.c
  * - Functions for initialization in ices
  * Copyright (c) 2000 Alexander Havng
- * Copyright (c) 2002-3 Brendan Cully <brendan@xiph.org>
+ * Copyright (c) 2002-4 Brendan Cully <brendan@xiph.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -48,6 +48,7 @@ void
 ices_setup_initialize (void)
 {
   ices_stream_t* stream;
+  ices_plugin_t* plugin;
   
   shout_init();
 
@@ -79,7 +80,16 @@ ices_setup_initialize (void)
 #ifdef HAVE_LIBLAME
   /* Initialize liblame for reeencoding */
   ices_reencode_initialize ();
+
+  while (ices_config.plugins && ices_config.plugins->init() < 0)
+    ices_config.plugins = ices_config.plugins->next;
+
+  for (plugin = ices_config.plugins; plugin && plugin->next; plugin = plugin->next)
+    if (plugin->next->init() < 0)
+      plugin->next = plugin->next->next;
 #endif
+
+  ices_log_debug("Startup complete\n");
 }
 
 /* Top level ices shutdown function.
@@ -88,6 +98,7 @@ void
 ices_setup_shutdown (void)
 {
   ices_stream_t* stream;
+  ices_plugin_t* plugin;
 
   /* Tell libshout to disconnect from server */
   for (stream = ices_config.streams; stream; stream = stream->next)
@@ -95,6 +106,9 @@ ices_setup_shutdown (void)
       shout_close (stream->conn);
 
 #ifdef HAVE_LIBLAME
+  for (plugin = ices_config.plugins; plugin; plugin = plugin->next)
+    plugin->shutdown();
+
   /* Order the reencoding engine to shutdown */
   ices_reencode_shutdown ();
 #endif
@@ -333,6 +347,11 @@ ices_setup_parse_command_line (ices_config_t *ices_config, char **argv,
 	  arg++;
 	  stream->bitrate = atoi (argv[arg]);
 	  break;
+        case 'C':
+	  arg++;
+	  if (atoi(argv[arg]) > 0)
+	    /* TODO: stack plugins */
+	    ices_config->plugins = crossfade_plugin(atoi(argv[arg]));
         case 'c':
 	  arg++;
 	  break;
@@ -523,11 +542,12 @@ ices_setup_activate_libshout_changes (const ices_config_t *ices_config)
 static void
 ices_setup_usage (void)
 {
-  printf ("This is ices " VERSION "\n");
-  printf ("ices <options>\n");
-  printf ("Options:\n");
-  printf ("\t-B (Background (daemon mode))\n");
-  printf ("\t-b <stream bitrate>\n");
+  printf ("This is ices " VERSION "\n"
+	  "ices <options>\n"
+	  "Options:\n"
+	  "\t-B (Background (daemon mode))\n"
+	  "\t-b <stream bitrate>\n"
+	  "\t-C <crossfade seconds>\n");
   printf ("\t-c <configfile>\n");
   printf ("\t-D <base directory>\n");
   printf ("\t-d <stream description>\n");
@@ -545,6 +565,7 @@ ices_setup_usage (void)
   printf ("\t-r (randomize playlist)\n");
   printf ("\t-s (private stream)\n");
   printf ("\t-S <perl|python|builtin>\n");
+  printf ("\t-t <http|xaudiocast|icy>\n");
   printf ("\t-u <stream url>\n");
   printf ("\t-v (verbose output)\n");
   printf ("\t-H <reencoded sample rate>\n");
@@ -570,6 +591,12 @@ ices_setup_version (void)
 #endif
 #ifdef HAVE_LIBVORBISFILE
   "Vorbis "
+#endif
+#ifdef HAVE_LIBFLAC
+  "FLAC "
+#endif
+#ifdef HAVE_LIBFAAD
+  "MP4"
 #endif
   "\n"
   "System configuration file: " ICES_ETCDIR "/ices.conf\n"
