@@ -1,7 +1,7 @@
 /* stream.c
  * - Functions for streaming in ices
  * Copyright (c) 2000 Alexander Havng
- * Copyright (c) 2001-3 Brendan Cully
+ * Copyright (c) 2001-4 Brendan Cully <brendan@xiph.org>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -17,6 +17,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
+ * $Id: stream.c 7428 2004-07-31 09:11:47Z brendan $
  */
 
 #include "definitions.h"
@@ -25,6 +26,12 @@
 #ifdef HAVE_LIBVORBISFILE
 #include "in_vorbis.h"
 #endif
+#ifdef HAVE_LIBFAAD
+#include "in_mp4.h"
+#endif
+#ifdef HAVE_LIBFLAC
+#include "in_flac.h"
+#endif
 
 #ifdef TIME_WITH_SYS_TIME
 #  include <sys/time.h>
@@ -150,6 +157,7 @@ stream_send (ices_config_t* config, input_stream_t* source)
 #ifdef HAVE_LIBLAME
   int decode = 0;
   buffer_t obuf;
+  ices_plugin_t *plugin;
   /* worst case decode: 22050 Hz at 8kbs = 44.1 samples/byte */
   static int16_t left[INPUT_BUFSIZ * 45];
   static int16_t right[INPUT_BUFSIZ * 45];
@@ -162,11 +170,16 @@ stream_send (ices_config_t* config, input_stream_t* source)
 
   if (config->reencode) {
     ices_reencode_reset (source);
-    for (stream = config->streams; stream; stream = stream->next)
-      if (stream->reencode && stream_needs_reencoding (source, stream)) {
-        decode = 1;
-        break;
-      }
+    if (config->plugins) {
+      decode = 1;
+      for (plugin = config->plugins; plugin; plugin = plugin->next)
+	plugin->new_track(source);
+    } else
+      for (stream = config->streams; stream; stream = stream->next)
+	if (stream->reencode && stream_needs_reencoding (source, stream)) {
+	  decode = 1;
+	  break;
+	}
   }
 
   if (decode) {
@@ -199,6 +212,13 @@ stream_send (ices_config_t* config, input_stream_t* source)
 #endif
     }
 
+#ifdef HAVE_LIBLAME
+    /* run output through plugin */
+    for (plugin = config->plugins; plugin; plugin = plugin->next)
+      if (samples)
+	samples = plugin->process(samples, left, right);
+#endif
+
     if (len == 0) {
       ices_log_debug ("Done sending");
       break;
@@ -207,14 +227,14 @@ stream_send (ices_config_t* config, input_stream_t* source)
       ices_log_error ("Read error: %s", ices_util_strerror (errno, namespace, 1024));
       goto err;
     }
-    
+
     do_sleep = 1;
     while (do_sleep) {
       rc = olen = 0;
       for (stream = config->streams; stream; stream = stream->next) {
         /* don't reencode if the source is MP3 and the same bitrate */
 #ifdef HAVE_LIBLAME
-        if (stream->reencode && stream_needs_reencoding (source, stream)) {
+        if (stream->reencode && (config->plugins || stream_needs_reencoding (source, stream))) {
           if (samples > 0) {
             /* for some reason we have to manually duplicate right from left to get
              * LAME to output stereo from a mono source */
@@ -247,9 +267,9 @@ stream_send (ices_config_t* config, input_stream_t* source)
 	            ices_log_debug ("Grew output buffer to %d bytes", obuf.len);
 	          } else
 	            ices_log_debug ("%d byte output buffer is too small", obuf.len);
-            } else if (olen > 0) {
-              rc = stream_send_data (stream, obuf.data, olen);
-            }
+		} else if (olen > 0) {
+		  rc = stream_send_data (stream, obuf.data, olen);
+		}
           }
         } else
 #endif
@@ -279,12 +299,13 @@ stream_send (ices_config_t* config, input_stream_t* source)
   }
 
 #ifdef HAVE_LIBLAME
-  for (stream = config->streams; stream; stream = stream->next)
-    if (stream->reencode && stream_needs_reencoding (source, stream)) {
-      len = ices_reencode_flush (stream, obuf.data, obuf.len);
-      if (len > 0)
-        rc = shout_send (stream->conn, obuf.data, len);
-    }
+  if (!config->plugins) /* flush is only necessary if we're not continuously reencoding */
+    for (stream = config->streams; stream; stream = stream->next)
+      if (stream->reencode && stream_needs_reencoding (source, stream)) {
+	len = ices_reencode_flush (stream, obuf.data, obuf.len);
+	if (len > 0)
+	  rc = stream_send_data (stream, obuf.data, len);
+      }
 
   if (obuf.data)
     free(obuf.data);
@@ -338,6 +359,24 @@ stream_open_source (input_stream_t* source)
     return -1;
   }
 
+#ifdef HAVE_LIBFLAC
+  if (!(rc = ices_flac_open (source, buf, len)))
+    return 0;
+  if (rc < 0) {
+    close(fd);
+    return -1;
+  }
+#endif
+
+#ifdef HAVE_LIBFAAD
+  if (!(rc = ices_mp4_open (source, buf, len)))
+    return 0;
+  if (rc < 0) {
+    close(fd);
+    return -1;
+  }
+#endif
+
   if (!(rc = ices_mp3_open (source, buf, len)))
     return 0;
   if (rc < 0) {
